@@ -1,10 +1,10 @@
 package Acme::Mitey::Cards::Card;
 
-our $VERSION   = '0.011';
+our $VERSION   = '0.012';
 our $AUTHORITY = 'cpan:TOBYINK';
 
-use Acme::Mitey::Cards::Mite qw( -bool -is carp );
-use Acme::Mitey::Cards::Types qw(:types);
+use Acme::Mitey::Cards::Mite qw( -all );
+use Acme::Mitey::Cards::Types qw( :types );
 
 has deck => (
 	is       => ro,
@@ -18,6 +18,10 @@ has reverse => (
 	builder  => sub { shift->deck->reverse },
 );
 
+signature_for to_string => (
+	pos => [],
+);
+
 sub to_string {
 	my $self = shift;
 
