@@ -1,10 +1,10 @@
 package Acme::Mitey::Cards::Card::Face;
 
-our $VERSION   = '0.011';
+our $VERSION   = '0.012';
 our $AUTHORITY = 'cpan:TOBYINK';
 
-use Acme::Mitey::Cards::Mite qw( -bool -is );
-use Acme::Mitey::Cards::Types qw(:types);
+use Acme::Mitey::Cards::Mite qw( -all );
+use Acme::Mitey::Cards::Types qw( :types );
 
 extends 'Acme::Mitey::Cards::Card';
 
@@ -23,12 +23,18 @@ has face => (
 	required => true,
 );
 
+signature_for face_abbreviation => (
+	pos => [],
+);
+
 sub face_abbreviation {
 	my $self = shift;
 
 	return substr( $self->face, 0, 1 );
 }
 
+signature_for '+to_string';
+
 sub to_string {
 	my $self = shift;
 
