@@ -1,10 +1,10 @@
 package Acme::Mitey::Cards::Hand;
 
-our $VERSION   = '0.011';
+our $VERSION   = '0.012';
 our $AUTHORITY = 'cpan:TOBYINK';
 
-use Acme::Mitey::Cards::Mite qw( -bool -is );
-use Acme::Mitey::Cards::Types qw(:types);
+use Acme::Mitey::Cards::Mite qw( -all );
+use Acme::Mitey::Cards::Types qw( :types );
 
 extends 'Acme::Mitey::Cards::Set';
 
